==> Miro-0.9.8.tgz: multimedia/miro/files/patch-platform_gtk-x11_setup.py <==
--- platform/gtk-x11/setup.py.orig	Tue Jul 17 21:32:42 2007
+++ platform/gtk-x11/setup.py	Sat Jul 21 15:53:42 2007
@@ -22,6 +22,7 @@
 ###############################################################################
 
 BOOST_LIB = 'boost_python'
+BOOST_LIB_PATH = '/usr/local/lib'
 
 ###############################################################################
 ## End of configuration. No user-servicable parts inside                     ##
@@ -159,6 +160,9 @@
             options_dict['library_dirs'].append(rest)
         elif prefix == '-l':
             options_dict['libraries'].append(rest)
+        elif prefix == '-W':
+            # throw away, it breaks cc1
+            continue
         else:
             options_dict['extra_compile_args'].append(comp)
     return options_dict
@@ -168,6 +172,7 @@
     Extension("miro.fasttypes", 
         sources = [os.path.join(portable_dir, 'fasttypes.cpp')],
         libraries = [BOOST_LIB],
+	library_dirs = [BOOST_LIB_PATH],
     )
 
 #### MozillaBrowser Extension ####
@@ -178,14 +183,17 @@
 if re.search("^xulrunner-xpcom", packages, re.MULTILINE):
     xpcom = 'xulrunner-xpcom'
     gtkmozembed = 'xulrunner-gtkmozembed'
-elif re.search("^mozilla-xpcom", packages, re.MULTILINE):
-    xpcom = 'mozilla-xpcom'
-    gtkmozembed = 'mozilla-gtkmozembed'
 elif re.search("^firefox-xpcom", packages, re.MULTILINE):
     xpcom = 'firefox-xpcom'
     gtkmozembed = 'firefox-gtkmozembed'
+elif re.search("^seamonkey-xpcom", packages, re.MULTILINE):
+    xpcom = 'seamonkey-xpcom'
+    gtkmozembed = 'seamonkey-gtkmozembed'
+elif re.search("^mozilla-xpcom", packages, re.MULTILINE):
+    xpcom = 'mozilla-xpcom'
+    gtkmozembed = 'mozilla-gtkmozembed'
 else:
-    sys.exit("Can't find xulrunner-xpcom, mozilla-xpcom or firefox-xpcom")
+    sys.exit("Can't find xulrunner-xpcom, mozilla-xpcom, firefox-xpcom or seamonkey-xpcom")
 mozilla_browser_options = parsePkgConfig("pkg-config" , 
         "gtk+-2.0 glib-2.0 pygtk-2.0 %s %s" % (gtkmozembed, xpcom))
 mozilla_lib_path = parsePkgConfig('pkg-config', 
@@ -272,7 +280,7 @@
      [os.path.join(platform_dir, 'miro.desktop')]),
     ('/usr/share/mime/packages', 
      [os.path.join(platform_dir, 'miro.xml')]),
-    ('/usr/share/man/man1',
+    ('/usr/local/man/man1',
      [os.path.join(platform_dir, 'miro.1.gz')]),
 ]

==> Miro-0.9.8.1.tgz: multimedia/miro/files/patch-platform_gtk-x11_setup.py <==
--- platform/gtk-x11/setup.py.orig	Tue Jul 24 21:18:15 2007
+++ platform/gtk-x11/setup.py	Sun Aug 12 17:13:51 2007
@@ -22,6 +22,7 @@
 ###############################################################################
 
 BOOST_LIB = 'boost_python'
+BOOST_LIB_PATH = '/usr/local/lib'
 
 ###############################################################################
 ## End of configuration. No user-servicable parts inside                     ##
@@ -159,6 +160,9 @@
             options_dict['library_dirs'].append(rest)
         elif prefix == '-l':
             options_dict['libraries'].append(rest)
+        elif prefix == '-W':
+            # throw away, it breaks cc1
+            continue
         else:
             options_dict['extra_compile_args'].append(comp)
     return options_dict
@@ -168,6 +172,7 @@
     Extension("miro.fasttypes", 
         sources = [os.path.join(portable_dir, 'fasttypes.cpp')],
         libraries = [BOOST_LIB],
+	library_dirs = [BOOST_LIB_PATH],
     )
 
 #### MozillaBrowser Extension ####
@@ -178,12 +183,15 @@
 if re.search("^xulrunner-xpcom", packages, re.MULTILINE):
     xpcom = 'xulrunner-xpcom'
     gtkmozembed = 'xulrunner-gtkmozembed'
-elif re.search("^mozilla-xpcom", packages, re.MULTILINE):
-    xpcom = 'mozilla-xpcom'
-    gtkmozembed = 'mozilla-gtkmozembed'
 elif re.search("^firefox-xpcom", packages, re.MULTILINE):
     xpcom = 'firefox-xpcom'
     gtkmozembed = 'firefox-gtkmozembed'
+elif re.search("^seamonkey-xpcom", packages, re.MULTILINE):
+    xpcom = 'seamonkey-xpcom'
+    gtkmozembed = 'seamonkey-gtkmozembed'
+elif re.search("^mozilla-xpcom", packages, re.MULTILINE):
+    xpcom = 'mozilla-xpcom'
+    gtkmozembed = 'mozilla-gtkmozembed'
 else:
     sys.exit("Can't find xulrunner-xpcom, mozilla-xpcom or firefox-xpcom")
 
@@ -285,7 +293,7 @@
      [os.path.join(platform_dir, 'miro.desktop')]),
     ('/usr/share/mime/packages', 
      [os.path.join(platform_dir, 'miro.xml')]),
-    ('/usr/share/man/man1',
+    ('/usr/local/man/man1',
      [os.path.join(platform_dir, 'miro.1.gz')]),
 ]
